@@ -46,7 +46,6 @@ ProcDPMSGetVersion(ClientPtr client)
 {
     /* REQUEST(xDPMSGetVersionReq); */
     xDPMSGetVersionReply rep;
-    int n;
 
     REQUEST_SIZE_MATCH(xDPMSGetVersionReq);
 
@@ -56,11 +55,11 @@ ProcDPMSGetVersion(ClientPtr client)
     rep.majorVersion = DPMSMajorVersion;
     rep.minorVersion = DPMSMinorVersion;
     if (client->swapped) {
-    	swaps(&rep.sequenceNumber, n);
-	swaps(&rep.majorVersion, n);
-	swaps(&rep.minorVersion, n);
+        swaps(&rep.sequenceNumber);
+        swaps(&rep.majorVersion);
+        swaps(&rep.minorVersion);
     }
-    WriteToClient(client, sizeof(xDPMSGetVersionReply), (char *)&rep);
+    WriteToClient(client, sizeof(xDPMSGetVersionReply), (char *) &rep);
     return Success;
 }
 
@@ -69,7 +68,6 @@ ProcDPMSCapable(ClientPtr client)
 {
     /* REQUEST(xDPMSCapableReq); */
     xDPMSCapableReply rep;
-    int n;
 
     REQUEST_SIZE_MATCH(xDPMSCapableReq);
 
@@ -79,9 +77,9 @@ ProcDPMSCapable(ClientPtr client)
     rep.capable = DPMSCapableFlag;
 
     if (client->swapped) {
-	swaps(&rep.sequenceNumber, n);
+        swaps(&rep.sequenceNumber);
     }
-    WriteToClient(client, sizeof(xDPMSCapableReply), (char *)&rep);
+    WriteToClient(client, sizeof(xDPMSCapableReply), (char *) &rep);
     return Success;
 }
 
@@ -90,7 +88,6 @@ ProcDPMSGetTimeouts(ClientPtr client)
 {
     /* REQUEST(xDPMSGetTimeoutsReq); */
     xDPMSGetTimeoutsReply rep;
-    int n;
 
     REQUEST_SIZE_MATCH(xDPMSGetTimeoutsReq);
 
@@ -102,12 +99,12 @@ ProcDPMSGetTimeouts(ClientPtr client)
     rep.off = DPMSOffTime / MILLI_PER_SECOND;
 
     if (client->swapped) {
-    	swaps(&rep.sequenceNumber, n);
-	swaps(&rep.standby, n);
-	swaps(&rep.suspend, n);
-	swaps(&rep.off, n);
+        swaps(&rep.sequenceNumber);
+        swaps(&rep.standby);
+        swaps(&rep.suspend);
+        swaps(&rep.off);
     }
-    WriteToClient(client, sizeof(xDPMSGetTimeoutsReply), (char *)&rep);
+    WriteToClient(client, sizeof(xDPMSGetTimeoutsReply), (char *) &rep);
     return Success;
 }
 
@@ -118,16 +115,14 @@ ProcDPMSSetTimeouts(ClientPtr client)
 
     REQUEST_SIZE_MATCH(xDPMSSetTimeoutsReq);
 
-    if ((stuff->off != 0)&&(stuff->off < stuff->suspend)) 
-    {
-	client->errorValue = stuff->off;
-	return BadValue;
+    if ((stuff->off != 0) && (stuff->off < stuff->suspend)) {
+        client->errorValue = stuff->off;
+        return BadValue;
+    }
+    if ((stuff->suspend != 0) && (stuff->suspend < stuff->standby)) {
+        client->errorValue = stuff->suspend;
+        return BadValue;
     }
-    if ((stuff->suspend != 0)&&(stuff->suspend < stuff->standby))
-    {
-	client->errorValue = stuff->suspend;
-	return BadValue;
-    }  
 
     DPMSStandbyTime = stuff->standby * MILLI_PER_SECOND;
     DPMSSuspendTime = stuff->suspend * MILLI_PER_SECOND;
@@ -145,9 +140,9 @@ ProcDPMSEnable(ClientPtr client)
     REQUEST_SIZE_MATCH(xDPMSEnableReq);
 
     if (DPMSCapableFlag) {
-	DPMSEnabled = TRUE;
-	if (!was_enabled)
-	    SetScreenSaverTimer();
+        DPMSEnabled = TRUE;
+        if (!was_enabled)
+            SetScreenSaverTimer();
     }
 
     return Success;
@@ -175,14 +170,13 @@ ProcDPMSForceLevel(ClientPtr client)
     REQUEST_SIZE_MATCH(xDPMSForceLevelReq);
 
     if (!DPMSEnabled)
-	return BadMatch;
+        return BadMatch;
 
     if (stuff->level != DPMSModeOn &&
         stuff->level != DPMSModeStandby &&
-        stuff->level != DPMSModeSuspend &&
-        stuff->level != DPMSModeOff) {
-	client->errorValue = stuff->level;
-	return BadValue;
+        stuff->level != DPMSModeSuspend && stuff->level != DPMSModeOff) {
+        client->errorValue = stuff->level;
+        return BadValue;
     }
 
     DPMSSet(client, stuff->level);
@@ -195,7 +189,6 @@ ProcDPMSInfo(ClientPtr client)
 {
     /* REQUEST(xDPMSInfoReq); */
     xDPMSInfoReply rep;
-    int n;
 
     REQUEST_SIZE_MATCH(xDPMSInfoReq);
 
@@ -206,51 +199,49 @@ ProcDPMSInfo(ClientPtr client)
     rep.state = DPMSEnabled;
 
     if (client->swapped) {
-    	swaps(&rep.sequenceNumber, n);
-	swaps(&rep.power_level, n);
+        swaps(&rep.sequenceNumber);
+        swaps(&rep.power_level);
     }
-    WriteToClient(client, sizeof(xDPMSInfoReply), (char *)&rep);
+    WriteToClient(client, sizeof(xDPMSInfoReply), (char *) &rep);
     return Success;
 }
 
 static int
-ProcDPMSDispatch (ClientPtr client)
+ProcDPMSDispatch(ClientPtr client)
 {
     REQUEST(xReq);
 
-    switch (stuff->data)
-    {
+    switch (stuff->data) {
     case X_DPMSGetVersion:
-	return ProcDPMSGetVersion(client);
+        return ProcDPMSGetVersion(client);
     case X_DPMSCapable:
-	return ProcDPMSCapable(client);
+        return ProcDPMSCapable(client);
     case X_DPMSGetTimeouts:
-	return ProcDPMSGetTimeouts(client);
+        return ProcDPMSGetTimeouts(client);
     case X_DPMSSetTimeouts:
-	return ProcDPMSSetTimeouts(client);
+        return ProcDPMSSetTimeouts(client);
     case X_DPMSEnable:
-	return ProcDPMSEnable(client);
+        return ProcDPMSEnable(client);
     case X_DPMSDisable:
-	return ProcDPMSDisable(client);
+        return ProcDPMSDisable(client);
     case X_DPMSForceLevel:
-	return ProcDPMSForceLevel(client);
+        return ProcDPMSForceLevel(client);
     case X_DPMSInfo:
-	return ProcDPMSInfo(client);
+        return ProcDPMSInfo(client);
     default:
-	return BadRequest;
+        return BadRequest;
     }
 }
 
 static int
 SProcDPMSGetVersion(ClientPtr client)
 {
-    int n;
     REQUEST(xDPMSGetVersionReq);
 
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     REQUEST_SIZE_MATCH(xDPMSGetVersionReq);
-    swaps(&stuff->majorVersion, n);
-    swaps(&stuff->minorVersion, n);
+    swaps(&stuff->majorVersion);
+    swaps(&stuff->minorVersion);
     return ProcDPMSGetVersion(client);
 }
 
@@ -258,9 +249,8 @@ static int
 SProcDPMSCapable(ClientPtr client)
 {
     REQUEST(xDPMSCapableReq);
-    int n;
 
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     REQUEST_SIZE_MATCH(xDPMSCapableReq);
 
     return ProcDPMSCapable(client);
@@ -270,9 +260,8 @@ static int
 SProcDPMSGetTimeouts(ClientPtr client)
 {
     REQUEST(xDPMSGetTimeoutsReq);
-    int n;
 
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     REQUEST_SIZE_MATCH(xDPMSGetTimeoutsReq);
 
     return ProcDPMSGetTimeouts(client);
@@ -282,14 +271,13 @@ static int
 SProcDPMSSetTimeouts(ClientPtr client)
 {
     REQUEST(xDPMSSetTimeoutsReq);
-    int n;
 
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     REQUEST_SIZE_MATCH(xDPMSSetTimeoutsReq);
 
-    swaps(&stuff->standby, n);
-    swaps(&stuff->suspend, n);
-    swaps(&stuff->off, n);
+    swaps(&stuff->standby);
+    swaps(&stuff->suspend);
+    swaps(&stuff->off);
     return ProcDPMSSetTimeouts(client);
 }
 
@@ -297,9 +285,8 @@ static int
 SProcDPMSEnable(ClientPtr client)
 {
     REQUEST(xDPMSEnableReq);
-    int n;
 
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     REQUEST_SIZE_MATCH(xDPMSEnableReq);
 
     return ProcDPMSEnable(client);
@@ -309,9 +296,8 @@ static int
 SProcDPMSDisable(ClientPtr client)
 {
     REQUEST(xDPMSDisableReq);
-    int n;
 
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     REQUEST_SIZE_MATCH(xDPMSDisableReq);
 
     return ProcDPMSDisable(client);
@@ -321,12 +307,11 @@ static int
 SProcDPMSForceLevel(ClientPtr client)
 {
     REQUEST(xDPMSForceLevelReq);
-    int n;
 
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     REQUEST_SIZE_MATCH(xDPMSForceLevelReq);
 
-    swaps(&stuff->level, n);
+    swaps(&stuff->level);
 
     return ProcDPMSForceLevel(client);
 }
@@ -335,38 +320,36 @@ static int
 SProcDPMSInfo(ClientPtr client)
 {
     REQUEST(xDPMSInfoReq);
-    int n;
 
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     REQUEST_SIZE_MATCH(xDPMSInfoReq);
 
     return ProcDPMSInfo(client);
 }
 
 static int
-SProcDPMSDispatch (ClientPtr client)
+SProcDPMSDispatch(ClientPtr client)
 {
     REQUEST(xReq);
-    switch (stuff->data)
-    {
+    switch (stuff->data) {
     case X_DPMSGetVersion:
-	return SProcDPMSGetVersion(client);
+        return SProcDPMSGetVersion(client);
     case X_DPMSCapable:
-	return SProcDPMSCapable(client);
+        return SProcDPMSCapable(client);
     case X_DPMSGetTimeouts:
-	return SProcDPMSGetTimeouts(client);
+        return SProcDPMSGetTimeouts(client);
     case X_DPMSSetTimeouts:
-	return SProcDPMSSetTimeouts(client);
+        return SProcDPMSSetTimeouts(client);
     case X_DPMSEnable:
-	return SProcDPMSEnable(client);
+        return SProcDPMSEnable(client);
     case X_DPMSDisable:
-	return SProcDPMSDisable(client);
+        return SProcDPMSDisable(client);
     case X_DPMSForceLevel:
-	return SProcDPMSForceLevel(client);
+        return SProcDPMSForceLevel(client);
     case X_DPMSInfo:
-	return SProcDPMSInfo(client);
+        return SProcDPMSInfo(client);
     default:
-	return BadRequest;
+        return BadRequest;
     }
 }
 
@@ -374,6 +357,6 @@ void
 DPMSExtensionInit(INITARGS)
 {
     AddExtension(DPMSExtensionName, 0, 0,
-		 ProcDPMSDispatch, SProcDPMSDispatch,
-		 NULL, StandardMinorOpcode);
+                 ProcDPMSDispatch, SProcDPMSDispatch,
+                 NULL, StandardMinorOpcode);
 }
